import os
import sys
def main():
    if len(sys.argv)<2:
        name_list = os.listdir()
        dict_category = {}
        dict_category['PDF file names'] = []
        dict_category['Text file names'] = []
        dict_category['Video file names'] = []
        dict_category['Image file names'] = []
        dict_category['Zip file names'] = []
        dict_category['Music file names'] = []
        dict_category['Python file names'] = []
        dict_category['Folder names'] = []
        python_files = []
        for i in name_list:
            if str.lower(i[-4:]) in ['.mp4','.webm','.mkv','.flv','.vob','.gif','.avi']:
                dict_category['Video file names'].append(i)
            elif str.lower(i[-4:]) in ['.pdf']:
                dict_category['PDF file names'].append(i)
            elif str.lower(i[-4:]) in ['.txt']:
                dict_category['Text file names'].append(i)
            elif str.lower(i[-4:]) in ['.zip']:
                dict_category['Zip file names'].append(i)
            elif str.lower(i[-4:]) in ['.jpg','.jpeg','.png','.svg','.avif']:
                dict_category['Image file names'].append(i)
            elif str.lower(i[-4:]) in ['.mp3']:
                dict_category['Music file names'].append(i)
            elif str.lower(i[-3:]) in ['.py']:
                dict_category['Python file names'].append(i)   
            else:
                dict_category['Folder names'].append(i)

        for t,k in dict_category.items():
            print('-----------------------------')
            print('-----------',t,'-------------')
            for names in k:
                print(names)
            print('-----------------------------')
    else:
        print("The function doesnot require any arguments/parameters, please only type 'tpyfilestructure' and hit enter")        
if __name__ == "__main__":
    main()


import pathlib
import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()


# This call to setup() does all the work
setuptools.setup(
    name="tpyfilestructure",
    version="0.0.1",
    description="Python package to read and display the file/folder names present in a directory",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/tarun571999/tpyfilestructure",
    author="Tharun Kumar T",
    author_email="tarunkumar571999@gmail.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
    ],
    packages=setuptools.find_packages(),
    entry_points={
        "console_scripts": [
            "tpyfilestructure=tpyfilestructure.__main__:main",
        ]
    },
    python_requires ='>=3.7',
)